Basic class

结果基础信息

Constructors

Basic.fromMap(Map map)
fromMap

Properties

所查询城市的天气预报网页
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String
接口更新时间: 2021-04-19T18:27+08:00
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited