HistoricalDailyWeather class

历史当天天气

Properties

date ↔ String
当天日期
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
humidity ↔ String
相对温度
getter/setter pair
moonPhase ↔ String
月相
getter/setter pair
moonrise ↔ String
月升时间
getter/setter pair
moonset ↔ String
月落时间
getter/setter pair
precip ↔ String
降雨量
getter/setter pair
pressure ↔ String
大气压强
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sunrise ↔ String
日出时间
getter/setter pair
sunset ↔ String
日落时间
getter/setter pair
tempMax ↔ String
最高温度
getter/setter pair
tempMin ↔ String
最低温度
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited