DailyIndices class

当天生活指数信息

Constructors

DailyIndices.fromMap(Map map)
fromMap

Properties

category ↔ String
生活指数预报级别名称
getter/setter pair
date ↔ String
预报日期,格式 yyyy-MM-dd
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
level ↔ String
生活指数预报等级
getter/setter pair
name ↔ String
生活指数类型名称
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
生活指数详细描述
getter/setter pair
type ↔ String
生活指数类型
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited