DailyIndicesResp class

天气生活指数查询 结果

Constructors

DailyIndicesResp.fromMap(Map map)
fromMap

Properties

code ↔ String
API状态码
getter/setter pair
dailyList ↔ List<DailyIndices>
天气生活指数
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
refer ↔ Refer
Refer 数据来源信息
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited