OceanCurrents class

潮流数据

Constructors

OceanCurrents.fromMap(Map<String, dynamic> map)

Properties

dir360 ↔ String
潮流360度方向
getter/setter pair
fxTime ↔ String
潮流最大流速时间
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speedMax ↔ String
潮流最大流速,单位:厘米/秒
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited