Refer class

数据源

Constructors

Refer.fromMap(Map map)
fromMap

Properties

hashCode → int
The hash code for this object.
no setterinherited
license ↔ List<String>
数据许可或版权声明
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sources ↔ List<String>
原始数据来源,或数据源说明
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited