WarningRsp class

灾害预警查询结果

Constructors

WarningRsp.fromMap(Map map)
fromMap

Properties

basic ↔ Basic
Basic 包含 接口更新时间, 所查询城市的天气预报网页
getter/setter pair
code ↔ String
API状态码
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
refer ↔ Refer
Refer 数据来源信息
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
warningList ↔ List<Warning>
WeatherNow 实时天气
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited